pub enum Index {
Assumed(u8),
Overridden(u8),
}Variants
Assumed(u8)
The index is assumed
The algorithm for assuming indices is as follows:
- Global index starts at 0
- The command iterates over its parameters
- If the parameter is single, it adds 1 to the global index
- If a group, it calculates the indexes for its parameters and adds them to the global index
- If a selection, add 1 to the global index, store the global index for each selection, and add the max value to the global index. All selections inside a selection will start off with the same index
Overridden(u8)
The index is set by the user
Implementations