pub enum ParameterKind {
Switch,
Variable,
SelfSwitch,
String,
Int,
IntBool,
Enum {
variants: Vec<(String, i8)>,
},
}Variants
Switch
Parameter is a switch
Variable
Parameter is a variable
SelfSwitch
Parameter is a self switch
String
Parameter is a string
Int
Parameter is a signed integer
IntBool
Parameter is a bool stored as an integer
Enum
Parameter is a choice between a set of enums
The variants are a Vec of (String, i8) with the String being the variant, and the i8 being the value