pub struct CommandDescription {
pub code: u16,
pub name: String,
pub description: String,
pub kind: CommandKind,
pub hidden: bool,
pub lumi_text: String,
pub guid: u64,
}Fields
code: u16The code of this command
name: StringThe name of the command
description: StringThe description for the command Shows up when hovering over the command and in the command ui
kind: CommandKindThe type of command this is
Hide this in the command ui
lumi_text: StringThe text used by lumi!
guid: u64A unique guid
Used mainly in command-gen to prevent conflicts with egui::Id
Implementations
Sourceimpl CommandDescription
impl CommandDescription
Sourcepub fn parameter_count(&self) -> u8
pub fn parameter_count(&self) -> u8
How many total parameters does the command have?