OptionVec

Struct OptionVec 

pub struct OptionVec<T> { /* private fields */ }
A vector that can contain unused indices.

Implementations

Source

impl<T> OptionVec<T>

pub fn new() -> Self

Create a new OptionVec with no elements.

pub fn len(&self) -> usize

pub fn size(&self) -> usize

pub fn is_empty(&self) -> bool

pub fn contains(&self, index: usize) -> bool

pub fn get(&self, index: usize) -> Option<&T>

pub fn get_mut(&mut self, index: usize) -> Option<&mut T>

pub fn capacity(&self) -> usize

pub fn reserve(&mut self, additional: usize)

pub fn clear(&mut self)

pub fn iter(&self) -> Iter<'_, T>

pub fn iter_mut(&mut self) -> IterMut<'_, T>

pub fn insert(&mut self, index: usize, element: T)

Write the element at the given index. If there is already an element at the given index, it will be overwritten. If there isn’t, a new element will be added at that index.

pub fn try_remove(&mut self, index: usize) -> Result<T, String>

Remove the element at the given index and return it. If the OptionVec is not big enough to contain this index, this will throw an error. If there isn’t an element at that index, this will throw an error.

pub fn option_remove(&mut self, index: usize) -> Option<T>

pub fn remove(&mut self, index: usize) -> T

Remove the element at the given index and return it. If the OptionVec is not big enough to contain this index, this will panic. If there isn’t an element at that index, this will panic.